@@ -188,13 +188,15 @@ class MicroHAL(object):
                     if not removable:
                         newdisk = Disk(self)
                     else:
-                        newdisk = RemovableDisk(self)
+                        if os.readlink(os.path.join("/sys/block",blockdevice,"device")).split(os.path.sep)[5].startswith("usb"):
+                            newdisk = USBDisk(self)
+                        else:
+                            newdisk = RemovableDisk(self)
                     newdisk.dev = fulldevice
                     newdisk.major = devnum
                     newdisk.removable = removable
-                    
-                    if not removable:
-                        # We have a not removable block device.
+                    if not removable or isinstance(newdisk, USBDisk):
+                        # We have a not removable block device or a USB Disk here.
                         partitions = os.listdir(os.path.join("/sys/block",blockdevice))
                         partitions.sort()
                         i = 1
@@ -363,8 +365,18 @@ class RemovableDisk(Disk):
         self.removable = True
 
     def getName(self):
-        return "Optical Disk"+self.getModelName()
-
+        return "Optical Disc "+self.getModelName()
+        
+############################################################################        
+class USBDisk(Disk):
+    def __init__(self,hal):
+        super(USBDisk,self).__init__(hal)
+        self.iconname = "hi16-usbpen"
+        self.removable = True
+        
+    def getName(self):
+        return "Removable USB Disk "+self.getModelName()
+        
 ############################################################################        
 class BurnerDisk(RemovableDisk):
     def __init__(self,hal):
