@@ -28,7 +28,7 @@ from pickle import Pickler,Unpickler
 import locale
 
 programname = "Services Configuration"
-version = "0.6.7"
+version = "0.7.0"
 
 # Holding the name of the distribution, defaults to ...
 DISTRO = "Mandrake"
@@ -392,7 +392,7 @@ class DebianService(Service):
         self.runlevels = []
         self.gotStatus = False
         self.statusable = False
-        self.status = str(i18n("not running"))
+        self.status = unicode(i18n("not running"))
         self.startpriority = "50"
         self.killpriority = "50"
         self.getStatusFrom = "pidfile"
