@@ -27,7 +27,7 @@ import unixauthdb
 import locale
 
 programname = "userconfig"
-version = "0.6.7"
+version = "0.7.0"
 # Are we running as a separate standalone application or in KControl?
 standalone = __name__=='__main__'
 
@@ -828,7 +828,8 @@ class UserEditDialog(KDialogBase):
         self.newgroup.setGroupname(self.__fudgeNewGroupName(self.userobj.getUsername()))
         self.userobj.setPrimaryGroup(self.newgroup)
 
-        self.selectedgroups = []
+        self.selectedgroups = [ u'dialout',u'cdrom',u'floppy',u'audio',u'video',
+                                u'plugdev',u'lpadmin',u'scanner']
         homedir = self.__fudgeNewHomeDirectory(self.userobj.getUsername())
         self.userobj.setHomeDirectory(homedir)
         self.homediredit.setText(homedir)
@@ -849,6 +850,7 @@ class UserEditDialog(KDialogBase):
         self.uidedit.setReadOnly(False)
         self.updatingGUI = False
         self.homedirectoryislinked = True
+        self.passwordedit.erase()
         if self.exec_loop()==QDialog.Accepted:
             self.__updateObjectFromGUI(self.userobj)
             
@@ -974,6 +976,11 @@ class UserEditDialog(KDialogBase):
         self.primarygroupedit.setCurrentText(primarygroupname)
         
         # Secondary Groups
+        try:
+            self.selectedgroups.remove('new_user')
+        except ValueError:
+            pass
+
         self.secondarygroupsedit.setText(unicode(i18n(", ")).join(self.selectedgroups))
 
         # If ShadowExpire is turn off then we change the radio box.
@@ -998,7 +1005,11 @@ class UserEditDialog(KDialogBase):
         self.maximumpasswordedit.setDisabled(d)
         self.disableexpireedit.setDisabled(d)
         
-        self.warningedit.setValue(self.userobj.getPasswordExpireWarning())
+        if self.userobj.getPasswordExpireWarning() is None:
+            self.warningedit.setValue(0)
+        else:
+            self.warningedit.setValue(self.userobj.getPasswordExpireWarning())
+        
         if self.userobj.getMaximumPasswordAge() is None:
             self.maximumpasswordedit.setValue(30)
         else:
